@@ -428,7 +428,7 @@ class RapidMinerGoClient():
             #allResults.append(r.json())
 
             print('Got execution result for  ', model)
-            #print('Response is: ', r.json())
+            print('Response is: ', r.json())
             result = {}
             result[model] = r.json()
             allResults.update(result)
@@ -526,20 +526,99 @@ class RapidMinerGoClient():
 
         return r.json()
 
-    def quick_automodel(self,training_data,label):
-        response_json = self.add_dataFrame(training_data)
-        data_id = response_json["id"]
-        print(data_id)
-        modeling_task = self.create_modeling_task(data_id)
-        print(modeling_task)
-        modeling_task_id = modeling_task["id"]
-        self.set_label(modeling_task_id, "Survived")
-        self.set_class_interest(modeling_task_id, 'Yes', 'No')
-        self.set_cost_matrix(modeling_task_id, [[1, -1], [-1, 1]])
-        self.start_execution(modeling_task_id)
-        self.get_modeling_execution(modeling_task_id)
-        result = self.get_execution_result(modeling_task_id)
+    # def quick_automodel(self,training_data,label):
+    #     response_json = self.add_dataFrame(training_data)
+    #     data_id = response_json["id"]
+    #     print(data_id)
+    #     modeling_task = self.create_modeling_task(data_id)
+    #     print(modeling_task)
+    #     modeling_task_id = modeling_task["id"]
+    #     self.set_label(modeling_task_id, "Survived")
+    #     self.set_class_interest(modeling_task_id, 'Yes', 'No')
+    #     self.set_cost_matrix(modeling_task_id, [[1, -1], [-1, 1]])
+    #     self.start_execution(modeling_task_id)
+    #     self.get_modeling_execution(modeling_task_id)
+    #     result = self.get_execution_result(modeling_task_id)
 
+    def quick_automodel(go_url, inputdata, label):
+        LABEL_ATTRIBUTE = label
+        # To refresh the changes made in AutoModelWeb
+       # To get the AMW instance
+        # connection(go_url, gouser, gopassword)
+
+        data = json_normalize(inputdata)
+
+        # dataframe to json
+        responseJSON = self.add_dataFrame(data)
+        dataId = responseJSON[DATA_ID]
+
+        modelingTask = self.create_modeling_task(dataId)
+        modelingTaskID = modelingTask[DATA_ID]
+
+        # setting label
+        self.set_label(modelingTaskID, LABEL_ATTRIBUTE)
+        # self.set_class_interest(modelingTaskID, 'Yes', 'No')
+        # jsonVal = self.set_cost_matrix(modelingTaskID, [[1, -1], [-1, 1]])
+        # print('TaskID:' + modelingTaskID)
+
+        # Initiating model training
+        self.start_execution(modelingTaskID)
+        flag = True
+        print('ExecutingModel...')
+        # Loops till all the task are completed
+        while (flag):
+            flag = False
+            r = self.get_modeling_execution(modelingTaskID)
+            states = map(lambda x: x[TASK_STATE], r)
+            for state in states:
+                if (str(state).strip() not in COMPLETE_STATUS):
+                    flag = True
+
+        print('Model Execution Completed')
+
+        # Obtaining the trained model results
+        result = self.get_execution_result(modelingTaskID)
+
+        # To find the best model**add or remove features if needed to get a value of more or less deep rooted in Json*
+        features = [CRITERIA, SUB_CRITERIA, PARAM]
+        bestModel = self.determine_best_model(features)
+
+        # Deploying the best model
+        global depID
+        depID = self.deploy_model(modelingTaskID, bestModel)
+        status = 'Failed'
+        if str(depID) != '':
+            status = 'Success'
+
+        # Binding DeploymentID, Status and Best Model together in a dictionary to return as a output
+        out_result = {DEPLOYMENT_ID: depID, STATUS: status, MODEL: bestModel}
+        final_out = json_normalize(out_result)
+        print('DeploymentID:' + str(depID))
+
+        # if platform == 'tabprep':
+        return out_result
+
+        # if platform == 'interactive':
+        #     modelInputs = jsonVal['modelInputs']
+
+        # To find the best model**add or remove features if needed to get a value of more or less deep rooted in Json*
+        #     features = [CRITERIA, SUB_CRITERIA]
+        #     jsontoDf = self.resultPerformancePercentageView(features)
+        #     out_result = ({'Input:': modelInputs, 'FinalMetrics':jsontoDf})
+        #     return out_result
+
+        # prediction = []
+        #
+        # # Number of records in input
+        # max_length = len(data.index)
+        # max_data_length = len(data.index)
+        #
+        # # Adding survived to a list
+        # for i in range(0, max_data_length):
+        #     prediction.append(data.iloc[i][label])
+        #
+        # print('returning result')
+        # return prediction
 
     # def quick_autoModel(self, dataframe, label):
         # print("Starting modeling process")
